@@ -1,9 +1,8 @@
 #
 # Copyright (C) 2012 - 2018 Satoru SATOH <ssato @ redhat.com>
-# Copyright (C) 2019 Satoru SATOH <satoru.satoh @ gmail.com>
-# License: MIT
+# Copyright (C) 2019 - 2021 Satoru SATOH <satoru.satoh @ gmail.com>
+# SPDX-License-Identifier: MIT
 #
-# pylint: disable=unused-argument
 r"""Abstract implementation of backend modules:
 
 Backend module must implement a parser class inherits :class:`Parser` or its
@@ -19,17 +18,16 @@ needed:
 """
 from __future__ import absolute_import
 
+import collections
 import functools
-import logging
-import os
+import io
+import pathlib
 
-import anyconfig.compat
 import anyconfig.globals
 import anyconfig.models.processor
 import anyconfig.utils
 
 
-LOGGER = logging.getLogger(__name__)
 TEXT_FILE = True
 
 
@@ -39,11 +37,7 @@ def ensure_outdir_exists(filepath):
 
     :param filepath: path of file to dump
     """
-    outdir = os.path.dirname(filepath)
-
-    if outdir and not os.path.exists(outdir):
-        LOGGER.debug("Making output dir: %s", outdir)
-        os.makedirs(outdir)
+    pathlib.Path(filepath).parent.mkdir(parents=True, exist_ok=True)
 
 
 def to_method(func):
@@ -69,7 +63,7 @@ def _not_implemented(*args, **kwargs):
     raise NotImplementedError()
 
 
-class TextFilesMixin(object):
+class TextFilesMixin:
     """Mixin class to open configuration files as a plain text.
 
     Arguments of :func:`open` is different depends on python versions.
@@ -100,7 +94,7 @@ class BinaryFilesMixin(TextFilesMixin):
     _open_flags = ('rb', 'wb')
 
 
-class LoaderMixin(object):
+class LoaderMixin:
     """
     Mixin class to load data.
 
@@ -163,7 +157,7 @@ class LoaderMixin(object):
         if _dicts and callable(_dicts[0]):
             return _dicts[0]
         if self.ordered() and options.get("ac_ordered", False):
-            return anyconfig.compat.OrderedDict
+            return collections.OrderedDict
 
         return dict
 
@@ -264,7 +258,7 @@ class LoaderMixin(object):
         if anyconfig.utils.is_stream_ioinfo(ioi):
             cnf = self.load_from_stream(ioi.src, container, **options)
         else:
-            if ac_ignore_missing and not os.path.exists(ioi.path):
+            if ac_ignore_missing and not pathlib.Path(ioi.path).exists():
                 return container()
 
             cnf = self.load_from_path(ioi.path, container, **options)
@@ -272,7 +266,7 @@ class LoaderMixin(object):
         return cnf
 
 
-class DumperMixin(object):
+class DumperMixin:
     """
     Mixin class to dump data.
 
@@ -367,7 +361,7 @@ class Parser(TextFilesMixin, LoaderMixin, DumperMixin,
 
     .. seealso:: the doc of :class:`anyconfig.models.processor.Processor`
     """
-    pass
+    _cid = "base"
 
 
 class FromStringLoaderMixin(LoaderMixin):
@@ -422,7 +416,7 @@ class FromStreamLoaderMixin(LoaderMixin):
 
         :return: Dict-like object holding config parameters
         """
-        return self.load_from_stream(anyconfig.compat.StringIO(content),
+        return self.load_from_stream(io.StringIO(content),
                                      container, **kwargs)
 
     def load_from_path(self, filepath, container, **kwargs):
@@ -490,7 +484,7 @@ class ToStreamDumperMixin(DumperMixin):
 
         :return: Dict-like object holding config parameters
         """
-        stream = anyconfig.compat.StringIO()
+        stream = io.StringIO()
         self.dump_to_stream(cnf, stream, **kwargs)
         return stream.getvalue()
 
@@ -513,7 +507,6 @@ class StringParser(Parser, FromStringLoaderMixin, ToStringDumperMixin):
 
     Parser classes inherit this class must define these methods.
     """
-    pass
 
 
 class StreamParser(Parser, FromStreamLoaderMixin, ToStreamDumperMixin):
@@ -523,7 +516,6 @@ class StreamParser(Parser, FromStreamLoaderMixin, ToStreamDumperMixin):
 
     Parser classes inherit this class must define these methods.
     """
-    pass
 
 
 def load_with_fn(load_fn, content_or_strm, container, allow_primitives=False,
