@@ -1,6 +1,7 @@
 #
-# Copyright (C) 2018 Satoru SATOH <ssato @ redhat.com>
-# License: MIT
+# Copyright (C) 2018 Satoru SATOH <ssato@redhat.com>
+# Copyright (C) 2019 - 2020 Satoru SATOH <satoru.satoh@gmail.com>
+# SPDX-License-Identifier: MIT
 #
 r"""Globals, functions common in some JSON backends:
 
@@ -9,7 +10,6 @@ Changelog:
 .. versionadded:: 0.9.8
 """
 import anyconfig.backend.base
-import anyconfig.compat
 
 
 JSON_LOAD_OPTS = ["cls", "object_hook", "parse_float", "parse_int",
@@ -20,12 +20,6 @@ JSON_DUMP_OPTS = ["skipkeys", "ensure_ascii", "check_circular", "allow_nan",
 
 JSON_DICT_OPTS = ["object_pairs_hook", "object_hook"]
 
-# It seems that 'encoding' argument is not allowed in json.load[s] and
-# json.dump[s] in JSON module in python 3.x.
-if not anyconfig.compat.IS_PYTHON_3:
-    JSON_LOAD_OPTS.append("encoding")
-    JSON_DUMP_OPTS.append("encoding")
-
 
 class Parser(anyconfig.backend.base.StringStreamFnParser):
     """
