@@ -1,6 +1,9 @@
 #
-# Copyright (C) 2017 Satoru SATOH <ssato redhat.com>
-# License: MIT
+# Copyright (C) 2017, 2018 Satoru SATOH <ssato@redhat.com>
+# Copyright (C) 2019 - 2020 Satoru SATOH <satoru.satoh@gmail.com>
+# SPDX-License-Identifier: MIT
+#
+# pylint: disable=bare-except
 #
 r"""anyconfig.query module to support query data with JMESPath expressions.
 
@@ -17,7 +20,7 @@ except ImportError:
     pass
 
 
-def query(data, jexp, **options):
+def query(data, jexp, **_options):
     """
     Filter data with given JMESPath expression.
 
@@ -37,9 +40,11 @@ def query(data, jexp, **options):
     except ValueError as exc:  # jmespath.exceptions.*Error inherit from it.
         return (data, exc)
 
-    except (NameError, AttributeError):
-        raise ValueError("Required 'jmespath' module is not available.")
+    except (NameError, AttributeError) as exc:
+        raise ValueError("Required 'jmespath' module is not available."
+                         ) from exc
 
-    return (None, exc)  # It should not reach here.
+    except:  # noqa: E722
+        return (None, exc)
 
 # vim:sw=4:ts=4:et:
