@@ -1,6 +1,6 @@
 #
-# Copyright (C) 2018, 2019 Satoru SATOH <satoru.satoh@gmail.com>
-# License: MIT
+# Copyright (C) 2018 - 2020 Satoru SATOH <satoru.satoh@gmail.com>
+# SPDX-License-Identifier: MIT
 #
 # pylint: disable=too-few-public-methods
 r"""Singleton class
@@ -13,7 +13,7 @@ from __future__ import absolute_import
 import threading
 
 
-class Singleton(object):
+class Singleton:
     """Singleton utilizes __new__ special method.
 
     .. note:: Inherited classes are equated with base class inherit this.
