@@ -1,12 +1,12 @@
 #
-# Copyright (C) 2013 - 2019 Satoru SATOH <satoru.satoh @ gmail.com>
+# Copyright (C) 2013 - 2021 Satoru SATOH <satoru.satoh @ gmail.com>
 # License: MIT
 #
 # pylint: disable=missing-docstring, invalid-name, too-many-public-methods
 from __future__ import absolute_import
 
 import os
-import os.path
+import pathlib
 import shutil
 import tempfile
 import unittest
@@ -26,7 +26,7 @@ CNF_0_PATH = tests.common.respath('00-cnf.yml')
 
 
 def _run(*args):
-    TT.main(["dummy"] + list(args))
+    return TT.main(["dummy"] + [str(a) for a in args])
 
 
 class Test_00(unittest.TestCase):
@@ -48,8 +48,10 @@ class RunTestBase(unittest.TestCase):
 
     def run_and_check_exit_code(self, args=None, code=0, _not=False,
                                 exc_cls=SystemExit):
+        if args is None:
+            args = []
         try:
-            TT.main(["dummy"] + ([] if args is None else args))
+            _run(*args)
         except exc_cls as exc:
             ecode = getattr(exc, "code", 1)
             (self.assertNotEqual if _not else self.assertEqual)(ecode, code)
@@ -57,10 +59,10 @@ class RunTestBase(unittest.TestCase):
 
 class RunTestWithTmpdir(RunTestBase):
     def setUp(self):
-        self.tmpdir = tempfile.mkdtemp()
+        self.tmpdir = pathlib.Path(tempfile.mkdtemp())
 
     def tearDown(self):
-        shutil.rmtree(self.tmpdir)
+        shutil.rmtree(str(self.tmpdir))
 
 
 class Test_10(RunTestBase):
@@ -94,21 +96,21 @@ class Test_12(RunTestWithTmpdir):
     infile = tests.common.respath('00-cnf.json')
 
     def test_60_unknown_out_file_type(self):
-        opath = os.path.join(self.tmpdir, "t.unknown_ext")
+        opath = str(self.tmpdir / "t.unknown_ext")
         self.run_and_check_exit_code([self.infile, "-o", opath], _not=True)
 
     def test_62_unknown_out_parser_type(self):
-        opath = os.path.join(self.tmpdir, "t.unknown_psr")
+        opath = str(self.tmpdir / "t.unknown_psr")
         self.run_and_check_exit_code([self.infile, "-O", opath], _not=True)
 
 
 class Test_20_Base(RunTestBase):
 
     def setUp(self):
-        self.workdir = tests.common.setup_workdir()
+        self.workdir = pathlib.Path(tests.common.setup_workdir())
 
     def tearDown(self):
-        tests.common.cleanup_workdir(self.workdir)
+        tests.common.cleanup_workdir(str(self.workdir))
 
     def _assert_run_and_exit(self, *args):
         self.assertRaises(SystemExit, _run, *args)
@@ -119,14 +121,14 @@ class Test_30_single_input(Test_20_Base):
     def test_10(self):
         a = dict(name="a", a=1, b=dict(b=[1, 2], c="C"))
 
-        infile = os.path.join(self.workdir, "a.json")
-        output = os.path.join(self.workdir, "b.json")
+        infile = self.workdir / "a.json"
+        output = self.workdir / "b.json"
 
         anyconfig.api.dump(a, infile)
-        self.assertTrue(os.path.exists(infile))
+        self.assertTrue(infile.exists())
 
-        TT.main(["dummy", "-o", output, infile])
-        self.assertTrue(os.path.exists(output))
+        _run("-o", output, infile)
+        self.assertTrue(output.exists())
 
     def test_20_wo_input_type(self):
         self._assert_run_and_exit("a.conf")
@@ -134,37 +136,37 @@ class Test_30_single_input(Test_20_Base):
     def test_30_w_get_option(self):
         d = dict(name="a", a=dict(b=dict(c=[1, 2], d="C")))
 
-        infile = os.path.join(self.workdir, "a.json")
-        output = os.path.join(self.workdir, "b.json")
+        infile = self.workdir / "a.json"
+        output = self.workdir / "b.json"
 
         anyconfig.api.dump(d, infile)
-        self.assertTrue(os.path.exists(infile))
+        self.assertTrue(infile.exists())
 
-        TT.main(["dummy", "-o", output, "--get", "a.b", infile])
-        self.assertTrue(os.path.exists(output))
+        _run("-o", output, "--get", "a.b", infile)
+        self.assertTrue(output.exists())
 
         x = anyconfig.api.load(output)
         self.assertEqual(x, d['a']['b'])
 
     def test_31_w_get_option_failure(self):
         (key, no_get_q) = ('a', "wrong_key_0.wrong_key_1")
-        infile = os.path.join(self.workdir, "a.json")
+        infile = self.workdir / "a.json"
         anyconfig.api.dump({key: "A"}, infile)
-        self.assertTrue(os.path.exists(infile))
+        self.assertTrue(infile.exists())
 
         self.run_and_check_exit_code(["--get", no_get_q, infile], 1)
 
     def test_32_w_set_option(self):
         d = dict(name="a", a=dict(b=dict(c=[1, 2], d="C")))
 
-        infile = os.path.join(self.workdir, "a.json")
-        output = os.path.join(self.workdir, "b.json")
+        infile = self.workdir / "a.json"
+        output = self.workdir / "b.json"
 
         anyconfig.api.dump(d, infile)
-        self.assertTrue(os.path.exists(infile))
+        self.assertTrue(infile.exists())
 
-        TT.main(["dummy", "-o", output, "--set", "a.b.d=E", infile])
-        self.assertTrue(os.path.exists(output))
+        _run("-o", output, "--set", "a.b.d=E", infile)
+        self.assertTrue(output.exists())
 
         ref = d.copy()
         ref['a']['b']['d'] = 'E'
@@ -173,11 +175,10 @@ class Test_30_single_input(Test_20_Base):
         self.assertEqual(x, ref)
 
     def test_40_ignore_missing(self):
-        infile = os.path.join(os.curdir, "conf_file_should_not_exist.json")
-        assert not os.path.exists(infile)
+        infile = pathlib.Path(os.curdir) / "conf_file_should_not_exist.json"
+        assert not infile.exists()
 
-        self.assertFalse(TT.main(["dummy", "-O", "json",
-                                  "--ignore-missing", infile]))
+        self.assertFalse(_run("-O", "json", "--ignore-missing", infile))
 
     @unittest.skipIf(not anyconfig.schema.JSONSCHEMA_IS_AVAIL,
                      "json schema lib is not available")
@@ -185,13 +186,13 @@ class Test_30_single_input(Test_20_Base):
         infile = CNF_0_PATH
         scmfile = tests.common.respath('00-scm.yml')
 
-        output = os.path.join(self.workdir, "output.json")
+        output = self.workdir / "output.json"
         self.run_and_check_exit_code(["--schema", scmfile, "--validate",
                                       infile], 0)
         self.run_and_check_exit_code(["--schema", scmfile, "-o", output,
                                       infile], 0)
 
-        infile2 = os.path.join(self.workdir, "input.yml")
+        infile2 = self.workdir / "input.yml"
         cnf = CNF_0.copy()
         cnf["a"] = "aaa"  # Validation should fail.
         anyconfig.api.dump(cnf, infile2)
@@ -203,27 +204,26 @@ class Test_30_single_input(Test_20_Base):
 
     def test_54_gen_schema_and_validate_with_it(self):
         cnf = dict(name="a", a=1, b=dict(b=[1, 2], c="C"))
-        infile = os.path.join(self.workdir, "cnf.json")
-        output = os.path.join(self.workdir, "out.json")
+        infile = self.workdir / "cnf.json"
+        output = self.workdir / "out.json"
         anyconfig.api.dump(cnf, infile)
 
         self.run_and_check_exit_code(["--gen-schema", "-o", output, infile], 0)
-        self.assertTrue(os.path.exists(output))
+        self.assertTrue(output.exists())
         self.run_and_check_exit_code(["--schema", output, "--validate",
                                       infile], 0)
 
     def test_60_w_arg_option(self):
         a = dict(name="a", a=1, b=dict(b=[1, 2], c="C"), d=[1, 2])
 
-        infile = os.path.join(self.workdir, "a.json")
-        output = os.path.join(self.workdir, "b.json")
+        infile = self.workdir / "a.json"
+        output = self.workdir / "b.json"
 
         anyconfig.api.dump(a, infile)
-        self.assertTrue(os.path.exists(infile))
+        self.assertTrue(infile.exists())
 
-        TT.main(["dummy", "-o", output, "-A",
-                 "a:10;name:x;d:3,4", infile])
-        self.assertTrue(os.path.exists(output))
+        _run("-o", output, "-A", "a:10;name:x;d:3,4", infile)
+        self.assertTrue(output.exists())
 
         x = anyconfig.api.load(output)
 
@@ -238,23 +238,23 @@ class Test_30_single_input(Test_20_Base):
     def test_70_no_template(self):
         a = dict(name="a", a=1, b=dict(b=[1, 2], c="C"))
 
-        infile = os.path.join(self.workdir, "a.json")
-        output = os.path.join(self.workdir, "b.json")
+        infile = self.workdir / "a.json"
+        output = self.workdir / "b.json"
 
         anyconfig.api.dump(a, infile)
-        self.assertTrue(os.path.exists(infile))
+        self.assertTrue(infile.exists())
 
-        TT.main(["dummy", "-o", output, infile])
-        self.assertTrue(os.path.exists(output))
+        _run("-o", output, infile)
+        self.assertTrue(output.exists())
 
     def test_80_w_extra_opts(self):
         infile = tests.common.respath('00-00-cnf.json')
-        output = os.path.join(self.workdir, "out.json")
+        output = self.workdir / "out.json"
         ref = tests.common.respath('00-00-cnf_indented.json')
 
-        TT.main(["dummy", "-o", output, "--extra-opts", "indent:2", infile])
-        self.assertTrue(os.path.exists(output))
-        self.assertEqual(open(output).read().strip().rstrip(),
+        _run("-o", output, "--extra-opts", "indent:2", infile)
+        self.assertTrue(output.exists())
+        self.assertEqual(output.read_text().strip().rstrip(),
                          open(ref).read().strip().rstrip())
 
 
@@ -267,38 +267,36 @@ class Test_40_multi_inputs(Test_20_Base):
         a = xs[0].copy()
         a.update(xs[1])
 
-        output = os.path.join(self.workdir, "b.json")
+        output = self.workdir / "b.json"
 
         inputs = []
         for i in [0, 1]:
-            infile = os.path.join(self.workdir, "a%d.json" % i)
+            infile = self.workdir / "a{!s}.json".format(i)
             inputs.append(infile)
 
             anyconfig.api.dump(xs[i], infile)
-            self.assertTrue(os.path.exists(infile))
+            self.assertTrue(infile.exists())
 
-        TT.main(["dummy", "-o", output] + inputs)
-        self.assertTrue(os.path.exists(output))
+        _run("-o", output, *inputs)
+        self.assertTrue(output.exists())
 
+    @unittest.skipIf(not anyconfig.template.SUPPORTED,
+                     "jinja2 is not available")
     def test_20_w_template(self):
-        if not anyconfig.template.SUPPORTED:
-            return
-
         infile = tests.common.respath('30-00-template-cnf.json')
-        output = os.path.join(self.workdir, "output.json")
+        output = self.workdir / "output.json"
 
-        TT.main(["dummy", "--template", "-o", output, infile])
-        self.assertTrue(os.path.exists(output))
+        _run("--template", "-o", output, infile)
+        self.assertTrue(output.exists())
 
+    @unittest.skipIf(not anyconfig.template.SUPPORTED,
+                     "jinja2 is not available")
     def test_30_w_template(self):
-        if not anyconfig.template.SUPPORTED:
-            return
-
         infile = tests.common.respath('30-*-template-cnf.json')
-        output = os.path.join(self.workdir, "output.json")
+        output = self.workdir / "output.json"
 
-        TT.main(["dummy", "--template", "-o", output, infile])
-        self.assertTrue(os.path.exists(output))
+        _run("--template", "-o", output, infile)
+        self.assertTrue(output.exists())
 
 
 class Test_50_others_w_input(Test_20_Base):
@@ -306,7 +304,7 @@ class Test_50_others_w_input(Test_20_Base):
     def setUp(self):
         super().setUp()
         dic = dict(name="a", a=1, b=dict(b=[1, 2], c="C"), d=[1, 2])
-        self.infile = os.path.join(self.workdir, "a.json")
+        self.infile = self.workdir / "a.json"
         anyconfig.api.dump(dic, self.infile)
 
     def test_10_output_wo_output_option_w_otype(self):
@@ -316,12 +314,12 @@ class Test_50_others_w_input(Test_20_Base):
         self.run_and_check_exit_code(["--itype", "json", self.infile])
 
     def test_20_no_out_dumper(self):
-        outfile = os.path.join(self.workdir, "out.conf")
+        outfile = self.workdir / "out.conf"
         self.run_and_check_exit_code(["-o", outfile, self.infile], 1)
 
     def test_22_no_out_dumper_nor_itype(self):
-        infile = self.infile.replace(".json", ".conf")
-        outfile = os.path.join(self.workdir, "out.conf")
+        infile = str(self.infile).replace(".json", ".conf")
+        outfile = self.workdir / "out.conf"
         self.run_and_check_exit_code(["-o", outfile, infile], 1)
 
     @unittest.skipIf(not getattr(anyconfig.query, "jmespath", False),
@@ -333,11 +331,11 @@ class Test_50_others_w_input(Test_20_Base):
 class Test_50_others_wo_input(Test_20_Base):
 
     def test_30_no_itype_and_otype(self):
-        outfile = os.path.join(self.workdir, "out.conf")
+        outfile = self.workdir / "out.conf"
         self.run_and_check_exit_code(["-o", outfile, "in.conf"], 1)
 
     def test_40_no_inputs__w_env_option(self):
-        output = os.path.join(self.workdir, "out.json")
+        output = self.workdir / "out.json"
         self.run_and_check_exit_code(["--env", "-o", output], 0)
         data = anyconfig.api.load(output)
 
